@@ -208,6 +208,8 @@ struct mosquitto {
 #endif
 	bool clean_session;
 #ifdef WITH_BROKER
+	char *old_id; /* for when a duplicate client connects, but we still want to
+					 know what the id was */
 	bool is_dropping;
 	bool is_bridge;
 	struct mosquitto__bridge *bridge;
